@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef GRANTLEETHEME_GENERICFORMATTER_H
-#define GRANTLEETHEME_GENERICFORMATTER_H
+#pragma once
 
 #include "grantleetheme_export.h"
 
@@ -15,7 +14,8 @@
 
 class QString;
 
-namespace GrantleeTheme {
+namespace GrantleeTheme
+{
 class GenericFormatterPrivate;
 
 /** Convenience class for using a Grantlee theme. */
@@ -45,4 +45,3 @@ private:
 };
 }
 
-#endif // GRANTLEETHEME_GENERICFORMATTER_H
